==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-AYvfJByqpx1IO6mgoYbKOM
key: prettyprinter-convert-ansi-wl-pprint-1.1-AYvfJByqpx1IO6mgoYbKOM
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: 6bc1259c2dd91cd8d1499ac5e81a8c16
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.6.4/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-AYvfJByqpx1IO6mgoYbKOM
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ base-4.12.0.0
    prettyprinter-1.2.1-D3LgkONL8k3FCoPBb2R7Pv
    prettyprinter-ansi-terminal-1.1.1.2-GaTJN6gj9r37mn9GNSjAQw
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-GEsZ2ShnD2JFExVb3JTn44
key: prettyprinter-convert-ansi-wl-pprint-1.1-GEsZ2ShnD2JFExVb3JTn44
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: d4861a78f5fdfecff36e527c74cabea0
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-GEsZ2ShnD2JFExVb3JTn44
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ base-4.12.0.0
    prettyprinter-1.2.1-8KxJCNGUCaOFkQGh9SBK5J
    prettyprinter-ansi-terminal-1.1.1.2-IaxFm1dE2Oh9eWOgSFICd1
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
